==> kumactl-2.5.2.tar.gz: kuma-2.5.2/pkg/api-server/customization/api_manager_test.go <==
package customization_test

import (
	"fmt"
	"io"
	"net/http"
	"strings"

	"github.com/emicklei/go-restful/v3"
	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"

	"github.com/kumahq/kuma/pkg/api-server/customization"
	api_server_config "github.com/kumahq/kuma/pkg/config/api-server"
	"github.com/kumahq/kuma/pkg/metrics"
	"github.com/kumahq/kuma/pkg/plugins/resources/memory"
)

var _ = Describe("API Manager", func() {
	It("should return the config", func() {
		// given
		cfg := api_server_config.DefaultApiServerConfig()

		// setup
		resourceStore := memory.NewStore()
		metrics, err := metrics.NewMetrics("Standalone")
		Expect(err).ToNot(HaveOccurred())
		wsManager := customization.NewAPIList()

		ws := new(restful.WebService).Path("foo")
		ws.Route(ws.GET("baz").To(func(request *restful.Request, response *restful.Response) {
			_ = response.WriteAsJson("bar")
		}))
		wsManager.Add(ws)

		apiServer := createTestApiServer(resourceStore, cfg, metrics, wsManager)

		stop := make(chan struct{})
		defer close(stop)
		go func() {
			defer GinkgoRecover()
			err := apiServer.Start(stop)
			Expect(err).ToNot(HaveOccurred())
		}()
		port := strings.Split(apiServer.Address(), ":")[1]

		// wait for the server
		Eventually(func() error {
			_, err := http.Get(fmt.Sprintf("http://localhost:%s/foo", port))
			return err
		}, "3s").ShouldNot(HaveOccurred())

		// when
		resp, err := http.Get(fmt.Sprintf("http://localhost:%s/foo/baz", port))
		Expect(err).ToNot(HaveOccurred())

		// then
		body, err := io.ReadAll(resp.Body)
		Expect(err).ToNot(HaveOccurred())

		// when
		Expect(string(body)).To(Equal("\"bar\"\n"))
	})
})

==> kumactl-2.9.3.tar.gz: kuma-2.9.3/pkg/api-server/customization/api_manager_test.go <==
package customization_test

import (
	"fmt"
	"io"
	"net/http"
	"strings"

	"github.com/emicklei/go-restful/v3"
	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"

	"github.com/kumahq/kuma/pkg/api-server/customization"
	api_server_config "github.com/kumahq/kuma/pkg/config/api-server"
	"github.com/kumahq/kuma/pkg/metrics"
	"github.com/kumahq/kuma/pkg/plugins/resources/memory"
)

var _ = Describe("API Manager", func() {
	It("should return the config", func() {
		// given
		cfg := api_server_config.DefaultApiServerConfig()

		// setup
		resourceStore := memory.NewStore()
		metrics, err := metrics.NewMetrics("Zone")
		Expect(err).ToNot(HaveOccurred())
		wsManager := customization.NewAPIList()

		ws := new(restful.WebService).Path("foo")
		ws.Route(ws.GET("baz").To(func(request *restful.Request, response *restful.Response) {
			_ = response.WriteAsJson("bar")
		}))
		wsManager.Add(ws)

		apiServer := createTestApiServer(resourceStore, cfg, metrics, wsManager)

		stop := make(chan struct{})
		defer close(stop)
		go func() {
			defer GinkgoRecover()
			err := apiServer.Start(stop)
			Expect(err).ToNot(HaveOccurred())
		}()
		port := strings.Split(apiServer.Address(), ":")[1]

		// wait for the server
		Eventually(func() error {
			_, err := http.Get(fmt.Sprintf("http://localhost:%s/foo", port))
			return err
		}, "3s").ShouldNot(HaveOccurred())

		// when
		resp, err := http.Get(fmt.Sprintf("http://localhost:%s/foo/baz", port))
		Expect(err).ToNot(HaveOccurred())

		// then
		body, err := io.ReadAll(resp.Body)
		Expect(err).ToNot(HaveOccurred())

		// when
		Expect(string(body)).To(Equal("\"bar\"\n"))
	})
})
